@@ -2,8 +2,10 @@ from minato.filesystems.filesystem import (  # noqa: F401
     FileSystem,
     delete,
     download,
+    exists,
     get_version,
     open_file,
+    upload,
 )
 from minato.filesystems.gcs import GCSFileSystem  # noqa: F401
 from minato.filesystems.http import HttpFileSystem  # noqa: F401
